@@ -19,6 +19,7 @@ tryCatch({
 error = function(e) {
   opts_chunk$set(eval = FALSE)
 })
+options(digits = 4)
 
 ## ----aliases-------------------------------------------------------------
 OR(OR(TRUE,
@@ -246,3 +247,37 @@ ggplot(ahull_dt) +
 
 
 
+## ----weighted_quantile-ex------------------------------------------------
+x <- 1:10
+w <- c(rep(1, 5), rep(2, 5))
+quantile(x, prob = c(0.25, 0.75), names = FALSE)
+
+weighted_quantile(x, w, p = c(0.25, 0.75))
+
+## ----mutate_ntile-ex-----------------------------------------------------
+flights %>%
+  as.data.table %>%
+  .[, .(year, month, day, origin, dest, distance)] %>%
+  mutate_ntile(distance, n = 5L)
+
+
+## ----mutate_ntile-ex-charonly--------------------------------------------
+flights %>%
+  as.data.table %>%
+  .[, .(year, month, day, origin, dest, distance)] %>%
+  mutate_ntile(distance, n = 5L)
+
+## ----mutate_ntile-ex-2---------------------------------------------------
+flights %>%
+  as.data.table %>%
+  mutate_ntile("distance",
+               n = 5L,
+               character.only = TRUE) %>%
+  .[, dep_delay := coalesce(dep_delay, 0)] %>%
+  .[, .(avgDelay = mean(dep_delay)), keyby = "distanceQuintile"]
+
+
+## ----longest-affix-------------------------------------------------------
+trim_common_affixes(c("CurrentHousingCosts(weekly)",
+                      "CurrentFuelCosts(weekly)"))
+
